@@ -680,3 +680,44 @@ read_pool_key(char *key_file_path)
 
 #undef LINELEN
 }
+
+/*
+ * Check password type is md5 hashed or not. recovery_password and
+ * wd_lifecheck_password are not allowed to be md5 hashed format.
+ * The kind of returns of this function is follow;
+ *  0: password is not md5 hashed
+ * -1: password is md5 hashed
+ * -2: password is not found
+ */
+int
+chceck_password_type_is_not_md5(char *username, char *password_in_config)
+{
+	PasswordType passwordType = PASSWORD_TYPE_UNKNOWN;
+	PasswordMapping *password_mapping = NULL;
+
+	/*
+	 * if the password specified in config is empty string or NULL look for the
+	 * password in pool_passwd file
+	 */
+	if (password_in_config == NULL || strlen(password_in_config) == 0)
+	{
+		password_mapping = pool_get_user_credentials(username);
+		if (password_mapping == NULL)
+		{
+			return -2;
+		}
+		passwordType = password_mapping->pgpoolUser.passwordType;
+	}
+	else
+	{
+		passwordType = get_password_type(password_in_config);
+	}
+
+	/* if the password type is MD5 hash return -1*/
+	if (passwordType == PASSWORD_TYPE_MD5)
+	{
+		return -1;
+	}
+
+	return 0;
+}
\ No newline at end of file
